Struct tokio_bin_process::event::Event
source · pub struct Event {
pub timestamp: String,
pub level: Level,
pub target: String,
pub fields: Fields,
pub span: HashMap<String, Value>,
pub spans: Vec<HashMap<String, Value>>,
}Expand description
Represents an event created by tracing.
It is not possible to construct one directly from a tracing event.
Instead its expected that they are returned by one of the methods on crate::BinProcess which retrives them by parsing tracing’s JSON output.
Fields
timestamp: StringThe timestamp of the event.
level: LevelThe level of the event.
target: StringThe target of the event, this is usually the module name of the code that triggered the event.
fields: FieldsContains the message and other fields included in the event.
span: HashMap<String, Value>The last span that was entered before the event was triggered.
spans: Vec<HashMap<String, Value>>Every span that was active while the event was triggered.
Implementations